import React from 'react'
import { th } from '@pubsweet/ui'
import styled from 'styled-components'
import { compose, withHandlers, setDisplayName } from 'recompose'

import {
  ConfirmationModal,
  withModal2,
} from 'pubsweet-component-modal/src/components'

import { DecisionForm } from './'

const Decision = ({ showDecisionModal }) => (
  <Root onClick={showDecisionModal}>Make decision</Root>
)

const ModalComponent = ({ type, ...rest }) => {
  switch (type) {
    case 'decision':
      return <DecisionForm {...rest} />
    default:
      return <ConfirmationModal {...rest} />
  }
}

export default compose(
  setDisplayName('EICDecisionRoot'),
  withModal2(() => ({
    modalComponent: ModalComponent,
  })),
  withHandlers({
    showDecisionModal: ({
      showModal,
      hideModal,
      fragmentId,
      collectionId,
      heRecommendation,
    }) => () => {
      showModal({
        type: 'decision',
        hideModal,
        heRecommendation,
        fragmentId,
        collectionId,
      })
    },
  }),
)(Decision)

// #region styled components
const Root = styled.div`
  align-items: center;
  background-color: ${th('colorPrimary')};
  color: ${th('colorTextReverse')};
  cursor: pointer;
  display: flex;
  font-family: ${th('fontInterface')};
  font-size: ${th('fontSizeBaseSmall')};
  height: calc(${th('subGridUnit')} * 5);
  justify-content: center;
  padding: 0 calc(${th('subGridUnit')} * 2);
  text-transform: uppercase;
`
// #endregion
